summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorDragorn421 <Dragorn421@users.noreply.github.com>2023-01-10 19:03:31 +0100
committerGitHub <noreply@github.com>2023-01-10 13:03:31 -0500
commit542012efa68d110d6b631f9d149f6e5f4e68cc8e (patch)
tree6da8592b14b6be82219c09189ad8aeef537362a3 /src
parentb4c97ce17eb35329b4a7e3d98d7f06d558683f6d (diff)
Fix misc 19 (#1488)
* "bgs sword" -> "biggoron sword" * Animation_ChangeImpl: last arg is `ANIMTAPER_` enum * TransitionTileStatus -> state * Tiny gbi.h formatting fixups * some cleanup on floormaster * misc float ops cleanup * sunsSongState = SUNSSONG_INACTIVE * continueFlag == CS_CMD_STOP * fix few camera names inconsistency * textual 0 padding? not on my lawn * libultra: construct address from end of dmem rather than oob from imem * more free1 -> 2 fixup
Diffstat (limited to 'src')
-rw-r--r--src/code/code_800BB0A0.c2
-rw-r--r--src/code/z_camera.c30
-rw-r--r--src/code/z_camera_data.inc.c36
-rw-r--r--src/code/z_message_PAL.c2
-rw-r--r--src/code/z_parameter.c4
-rw-r--r--src/code/z_player_lib.c10
-rw-r--r--src/code/z_sram.c2
-rw-r--r--src/libultra/io/sptask.c2
-rw-r--r--src/overlays/actors/ovl_Door_Warp1/z_door_warp1.c8
-rw-r--r--src/overlays/actors/ovl_En_Am/z_en_am.c6
-rw-r--r--src/overlays/actors/ovl_En_Floormas/z_en_floormas.c132
-rw-r--r--src/overlays/actors/ovl_En_Floormas/z_en_floormas.h2
-rw-r--r--src/overlays/actors/ovl_En_GirlA/z_en_girla.c2
-rw-r--r--src/overlays/actors/ovl_En_Gm/z_en_gm.c2
-rw-r--r--src/overlays/actors/ovl_En_Go2/z_en_go2.c2
-rw-r--r--src/overlays/actors/ovl_En_Horse/z_en_horse.c2
-rw-r--r--src/overlays/actors/ovl_En_Skj/z_en_skj.c2
-rw-r--r--src/overlays/actors/ovl_player_actor/z_player.c12
18 files changed, 126 insertions, 132 deletions
diff --git a/src/code/code_800BB0A0.c b/src/code/code_800BB0A0.c
index 8dfd375e1..e525a0069 100644
--- a/src/code/code_800BB0A0.c
+++ b/src/code/code_800BB0A0.c
@@ -61,7 +61,7 @@ s32 func_800BB2B4(Vec3f* pos, f32* roll, f32* fov, CutsceneCameraPoint* point, s
}
*curFrame += advance;
if (*curFrame >= 1) {
- if (point[++*keyFrame + 3].continueFlag == -1) {
+ if (point[++*keyFrame + 3].continueFlag == CS_CMD_STOP) {
*keyFrame = 0;
ret = true;
}
diff --git a/src/code/z_camera.c b/src/code/z_camera.c
index f7641f471..e83a0e918 100644
--- a/src/code/z_camera.c
+++ b/src/code/z_camera.c
@@ -487,12 +487,12 @@ Vec3s* Camera_GetBgCamFuncDataUnderPlayer(Camera* camera, u16* bgCamCount) {
CollisionPoly* floorPoly;
s32 pad;
s32 bgId;
- PosRot playerPosShape;
+ PosRot playerPosRot;
- Actor_GetWorldPosShapeRot(&playerPosShape, &camera->player->actor);
- playerPosShape.pos.y += Player_GetHeight(camera->player);
+ Actor_GetWorldPosShapeRot(&playerPosRot, &camera->player->actor);
+ playerPosRot.pos.y += Player_GetHeight(camera->player);
- if (BgCheck_EntityRaycastDown3(&camera->play->colCtx, &floorPoly, &bgId, &playerPosShape.pos) == BGCHECK_Y_MIN) {
+ if (BgCheck_EntityRaycastDown3(&camera->play->colCtx, &floorPoly, &bgId, &playerPosRot.pos) == BGCHECK_Y_MIN) {
// no floor
return NULL;
}
@@ -508,14 +508,14 @@ Vec3s* Camera_GetBgCamFuncDataUnderPlayer(Camera* camera, u16* bgCamCount) {
* Returns the camera data index otherwise.
*/
s32 Camera_GetWaterBoxBgCamIndex(Camera* camera, f32* waterY) {
- PosRot playerPosShape;
+ PosRot playerPosRot;
WaterBox* waterBox;
s32 bgCamIndex;
- Actor_GetWorldPosShapeRot(&playerPosShape, &camera->player->actor);
- *waterY = playerPosShape.pos.y;
+ Actor_GetWorldPosShapeRot(&playerPosRot, &camera->player->actor);
+ *waterY = playerPosRot.pos.y;
- if (!WaterBox_GetSurface1(camera->play, &camera->play->colCtx, playerPosShape.pos.x, playerPosShape.pos.z, waterY,
+ if (!WaterBox_GetSurface1(camera->play, &camera->play->colCtx, playerPosRot.pos.x, playerPosRot.pos.z, waterY,
&waterBox)) {
// player's position is not in a water box.
*waterY = BGCHECK_Y_MIN;
@@ -7144,29 +7144,29 @@ void Camera_Stub80058140(Camera* camera) {
}
void Camera_InitDataUsingPlayer(Camera* camera, Player* player) {
- PosRot playerPosShape;
+ PosRot playerPosRot;
VecGeo eyeNextAtOffset;
s32 bgId;
- Vec3f floorPos;
+ Vec3f floorNorm;
s32 upXZ;
f32 playerToAtOffsetY;
Vec3f* eye = &camera->eye;
Vec3f* at = &camera->at;
Vec3f* eyeNext = &camera->eyeNext;
- Actor_GetWorldPosShapeRot(&playerPosShape, &player->actor);
+ Actor_GetWorldPosShapeRot(&playerPosRot, &player->actor);
playerToAtOffsetY = Player_GetHeight(player);
camera->player = player;
- camera->playerPosRot = playerPosShape;
+ camera->playerPosRot = playerPosRot;
camera->dist = eyeNextAtOffset.r = 180.0f;
- camera->inputDir.y = playerPosShape.rot.y;
+ camera->inputDir.y = playerPosRot.rot.y;
eyeNextAtOffset.yaw = camera->inputDir.y - 0x7FFF;
camera->inputDir.x = eyeNextAtOffset.pitch = 0x71C;
camera->inputDir.z = 0;
camera->camDir = camera->inputDir;
camera->xzSpeed = 0.0f;
camera->playerPosDelta.y = 0.0f;
- camera->at = playerPosShape.pos;
+ camera->at = playerPosRot.pos;
camera->at.y += playerToAtOffsetY;
camera->playerToAtOffset.x = 0;
@@ -7182,7 +7182,7 @@ void Camera_InitDataUsingPlayer(Camera* camera, Player* player) {
camera->up.y = 1.0f;
camera->up.x = upXZ;
- if (Camera_GetFloorYNorm(camera, &floorPos, at, &bgId) != BGCHECK_Y_MIN) {
+ if (Camera_GetFloorYNorm(camera, &floorNorm, at, &bgId) != BGCHECK_Y_MIN) {
camera->bgId = bgId;
}
diff --git a/src/code/z_message_PAL.c b/src/code/z_message_PAL.c
index 4694e24f9..b0805ba3b 100644
--- a/src/code/z_message_PAL.c
+++ b/src/code/z_message_PAL.c
@@ -1609,7 +1609,7 @@ void Message_OpenText(PlayState* play, u16 textId) {
// Increments text id based on piece of heart count, assumes the piece of heart text is all
// in order and that you don't have more than the intended amount of heart pieces.
textId += (gSaveContext.inventory.questItems & 0xF0000000 & 0xF0000000) >> QUEST_HEART_PIECE_COUNT;
- } else if (msgCtx->textId == 0xC && CHECK_OWNED_EQUIP(EQUIP_TYPE_SWORD, EQUIP_INV_SWORD_BGS)) {
+ } else if (msgCtx->textId == 0xC && CHECK_OWNED_EQUIP(EQUIP_TYPE_SWORD, EQUIP_INV_SWORD_BIGGORON)) {
textId = 0xB; // Traded Giant's Knife for Biggoron Sword
} else if (msgCtx->textId == 0xB4 && GET_EVENTCHKINF(EVENTCHKINF_96)) {
textId = 0xB5; // Destroyed Gold Skulltula
diff --git a/src/code/z_parameter.c b/src/code/z_parameter.c
index 00d16db9a..bb90b2f7d 100644
--- a/src/code/z_parameter.c
+++ b/src/code/z_parameter.c
@@ -1282,7 +1282,7 @@ void Interface_InitHorsebackArchery(PlayState* play) {
}
void func_800849EC(PlayState* play) {
- gSaveContext.inventory.equipment |= OWNED_EQUIP_FLAG(EQUIP_TYPE_SWORD, EQUIP_INV_SWORD_BGS);
+ gSaveContext.inventory.equipment |= OWNED_EQUIP_FLAG(EQUIP_TYPE_SWORD, EQUIP_INV_SWORD_BIGGORON);
gSaveContext.inventory.equipment ^= OWNED_EQUIP_FLAG_ALT(EQUIP_TYPE_SWORD, EQUIP_INV_SWORD_BROKENGIANTKNIFE);
if (CHECK_OWNED_EQUIP_ALT(EQUIP_TYPE_SWORD, EQUIP_INV_SWORD_BROKENGIANTKNIFE)) {
@@ -1419,7 +1419,7 @@ u8 Item_Give(PlayState* play, u8 item) {
gSaveContext.swordHealth = 8;
if (ALL_EQUIP_VALUE(EQUIP_TYPE_SWORD) ==
- ((1 << EQUIP_INV_SWORD_KOKIRI) | (1 << EQUIP_INV_SWORD_MASTER) | (1 << EQUIP_INV_SWORD_BGS) |
+ ((1 << EQUIP_INV_SWORD_KOKIRI) | (1 << EQUIP_INV_SWORD_MASTER) | (1 << EQUIP_INV_SWORD_BIGGORON) |
(1 << EQUIP_INV_SWORD_BROKENGIANTKNIFE))) {
gSaveContext.inventory.equipment ^=
OWNED_EQUIP_FLAG_ALT(EQUIP_TYPE_SWORD, EQUIP_INV_SWORD_BROKENGIANTKNIFE);
diff --git a/src/code/z_player_lib.c b/src/code/z_player_lib.c
index 83ed0dc15..624e94d39 100644
--- a/src/code/z_player_lib.c
+++ b/src/code/z_player_lib.c
@@ -26,7 +26,7 @@ u8 sActionModelGroups[PLAYER_IA_MAX] = {
PLAYER_MODELGROUP_10, // PLAYER_IA_FISHING_POLE
PLAYER_MODELGROUP_SWORD, // PLAYER_IA_SWORD_MASTER
PLAYER_MODELGROUP_SWORD, // PLAYER_IA_SWORD_KOKIRI
- PLAYER_MODELGROUP_BGS, // PLAYER_IA_SWORD_BGS
+ PLAYER_MODELGROUP_BGS, // PLAYER_IA_SWORD_BIGGORON
PLAYER_MODELGROUP_10, // PLAYER_IA_DEKU_STICK
PLAYER_MODELGROUP_HAMMER, // PLAYER_IA_HAMMER
PLAYER_MODELGROUP_BOW_SLINGSHOT, // PLAYER_IA_BOW
@@ -723,7 +723,7 @@ s32 Player_GetMeleeWeaponHeld(Player* this) {
}
s32 Player_HoldsTwoHandedWeapon(Player* this) {
- if ((this->heldItemAction >= PLAYER_IA_SWORD_BGS) && (this->heldItemAction <= PLAYER_IA_HAMMER)) {
+ if ((this->heldItemAction >= PLAYER_IA_SWORD_BIGGORON) && (this->heldItemAction <= PLAYER_IA_HAMMER)) {
return 1;
} else {
return 0;
@@ -731,7 +731,7 @@ s32 Player_HoldsTwoHandedWeapon(Player* this) {
}
s32 Player_HoldsBrokenKnife(Player* this) {
- return (this->heldItemAction == PLAYER_IA_SWORD_BGS) && (gSaveContext.swordHealth <= 0.0f);
+ return (this->heldItemAction == PLAYER_IA_SWORD_BIGGORON) && (gSaveContext.swordHealth <= 0.0f);
}
s32 Player_ActionToBottle(Player* this, s32 itemAction) {
@@ -1666,7 +1666,7 @@ u32 func_80091738(PlayState* play, u8* segment, SkelAnime* skelAnime) {
u8 sPauseModelGroupBySword[] = {
PLAYER_MODELGROUP_SWORD, // PLAYER_SWORD_KOKIRI
PLAYER_MODELGROUP_SWORD, // PLAYER_SWORD_MASTER
- PLAYER_MODELGROUP_BGS, // PLAYER_SWORD_BGS
+ PLAYER_MODELGROUP_BGS, // PLAYER_SWORD_BIGGORON
};
s32 Player_OverrideLimbDrawPause(PlayState* play, s32 limbIndex, Gfx** dList, Vec3f* pos, Vec3s* rot, void* arg) {
@@ -1836,7 +1836,7 @@ void Player_DrawPause(PlayState* play, u8* segment, SkelAnime* skelAnime, Vec3f*
srcTable = gLinkPauseChildJointTable;
}
} else {
- if (sword == PLAYER_SWORD_BGS) {
+ if (sword == PLAYER_SWORD_BIGGORON) {
srcTable = gLinkPauseAdultBgsJointTable;
} else if (shield != PLAYER_SHIELD_NONE) {
srcTable = gLinkPauseAdultShieldJointTable;
diff --git a/src/code/z_sram.c b/src/code/z_sram.c
index 0e87d045c..7f9eea58e 100644
--- a/src/code/z_sram.c
+++ b/src/code/z_sram.c
@@ -315,7 +315,7 @@ static Inventory sDebugSaveInventory = {
// equipment
((((1 << EQUIP_INV_SWORD_KOKIRI) << (EQUIP_TYPE_SWORD * 4)) |
((1 << EQUIP_INV_SWORD_MASTER) << (EQUIP_TYPE_SWORD * 4)) |
- ((1 << EQUIP_INV_SWORD_BGS) << (EQUIP_TYPE_SWORD * 4))) |
+ ((1 << EQUIP_INV_SWORD_BIGGORON) << (EQUIP_TYPE_SWORD * 4))) |
(((1 << EQUIP_INV_SHIELD_DEKU) << (EQUIP_TYPE_SHIELD * 4)) |
((1 << EQUIP_INV_SHIELD_HYLIAN) << (EQUIP_TYPE_SHIELD * 4)) |
((1 << EQUIP_INV_SHIELD_MIRROR) << (EQUIP_TYPE_SHIELD * 4))) |
diff --git a/src/libultra/io/sptask.c b/src/libultra/io/sptask.c
index 8b3286a45..be805ab5c 100644
--- a/src/libultra/io/sptask.c
+++ b/src/libultra/io/sptask.c
@@ -41,7 +41,7 @@ void osSpTaskLoad(OSTask* intp) {
while (__osSpSetPc((void*)SP_IMEM_START) == -1) {
;
}
- while (__osSpRawStartDma(OS_WRITE, (void*)(SP_IMEM_START - sizeof(*tp)), tp, sizeof(OSTask)) == -1) {
+ while (__osSpRawStartDma(OS_WRITE, (void*)(SP_DMEM_END + 1 - sizeof(OSTask)), tp, sizeof(OSTask)) == -1) {
;
}
while (__osSpDeviceBusy()) {
diff --git a/src/overlays/actors/ovl_Door_Warp1/z_door_warp1.c b/src/overlays/actors/ovl_Door_Warp1/z_door_warp1.c
index c7d068cfb..2c70ef18b 100644
--- a/src/overlays/actors/ovl_Door_Warp1/z_door_warp1.c
+++ b/src/overlays/actors/ovl_Door_Warp1/z_door_warp1.c
@@ -186,7 +186,7 @@ void DoorWarp1_SetupWarp(DoorWarp1* this, PlayState* play) {
void DoorWarp1_SetupAdultDungeonWarp(DoorWarp1* this, PlayState* play) {
SkelAnime_Init(play, &this->skelAnime, &gWarpCrystalSkel, &gWarpCrystalAnim, NULL, NULL, 0);
- Animation_ChangeImpl(&this->skelAnime, &gWarpCrystalAnim, 1.0f, 1.0f, 1.0f, ANIMMODE_ONCE, 40.0f, 1);
+ Animation_ChangeImpl(&this->skelAnime, &gWarpCrystalAnim, 1.0f, 1.0f, 1.0f, ANIMMODE_ONCE, 40.0f, ANIMTAPER_ACCEL);
this->scale = 0;
this->unk_1AE = -140;
@@ -215,7 +215,7 @@ void DoorWarp1_SetupBlueCrystal(DoorWarp1* this, PlayState* play) {
SkelAnime_Init(play, &this->skelAnime, &gWarpCrystalSkel, &gWarpCrystalAnim, NULL, NULL, 0);
Animation_ChangeImpl(&this->skelAnime, &gWarpCrystalAnim, 0, Animation_GetLastFrame(&gWarpCrystalAnim),
- Animation_GetLastFrame(&gWarpCrystalAnim), ANIMMODE_ONCE, 0.0f, 1);
+ Animation_GetLastFrame(&gWarpCrystalAnim), ANIMMODE_ONCE, 0.0f, ANIMTAPER_ACCEL);
this->skelAnime.curFrame = Animation_GetLastFrame(&gWarpCrystalAnim);
this->scale = 10;
@@ -244,7 +244,7 @@ void DoorWarp1_SetupBlueCrystal(DoorWarp1* this, PlayState* play) {
void DoorWarp1_SetupPurpleCrystal(DoorWarp1* this, PlayState* play) {
SkelAnime_Init(play, &this->skelAnime, &gWarpCrystalSkel, &gWarpCrystalAnim, NULL, NULL, 0);
Animation_ChangeImpl(&this->skelAnime, &gWarpCrystalAnim, 0, Animation_GetLastFrame(&gWarpCrystalAnim),
- Animation_GetLastFrame(&gWarpCrystalAnim), ANIMMODE_ONCE, 0.0f, 1);
+ Animation_GetLastFrame(&gWarpCrystalAnim), ANIMMODE_ONCE, 0.0f, ANIMTAPER_ACCEL);
this->skelAnime.curFrame = Animation_GetLastFrame(&gWarpCrystalAnim);
this->unk_1AE = 120;
@@ -668,7 +668,7 @@ void func_8099A508(DoorWarp1* this, PlayState* play) {
Audio_PlaySfxGeneral(NA_SE_EV_LINK_WARP, &player->actor.projectedPos, 4, &gSfxDefaultFreqAndVolScale,
&gSfxDefaultFreqAndVolScale, &gSfxDefaultReverb);
Animation_ChangeImpl(&this->skelAnime, &gWarpCrystalAnim, 1.0f, Animation_GetLastFrame(&gWarpCrystalAnim),
- Animation_GetLastFrame(&gWarpCrystalAnim), ANIMMODE_ONCE, 40.0f, 1);
+ Animation_GetLastFrame(&gWarpCrystalAnim), ANIMMODE_ONCE, 40.0f, ANIMTAPER_ACCEL);
this->unk_1B2 = 0x32;
DoorWarp1_SetupAction(this, DoorWarp1_AdultWarpOut);
diff --git a/src/overlays/actors/ovl_En_Am/z_en_am.c b/src/overlays/actors/ovl_En_Am/z_en_am.c
index 97e2113cd..e40bf546d 100644
--- a/src/overlays/actors/ovl_En_Am/z_en_am.c
+++ b/src/overlays/actors/ovl_En_Am/z_en_am.c
@@ -112,9 +112,9 @@ static ColliderQuadInit sQuadInit = {
};
typedef enum {
- /* 00 */ AM_DMGEFF_NONE, // used by anything that cant kill the armos
- /* 01 */ AM_DMGEFF_NUT,
- /* 06 */ AM_DMGEFF_STUN = 6, // doesn't include deku nuts
+ /* 0 */ AM_DMGEFF_NONE, // used by anything that cant kill the armos
+ /* 1 */ AM_DMGEFF_NUT,
+ /* 6 */ AM_DMGEFF_STUN = 6, // doesn't include deku nuts
/* 13 */ AM_DMGEFF_ICE = 13,
/* 14 */ AM_DMGEFF_MAGIC_FIRE_LIGHT,
/* 15 */ AM_DMGEFF_KILL // any damage source that can kill the armos (and isn't a special case)
diff --git a/src/overlays/actors/ovl_En_Floormas/z_en_floormas.c b/src/overlays/actors/ovl_En_Floormas/z_en_floormas.c
index d3d1a104b..2f4b418cd 100644
--- a/src/overlays/actors/ovl_En_Floormas/z_en_floormas.c
+++ b/src/overlays/actors/ovl_En_Floormas/z_en_floormas.c
@@ -12,8 +12,8 @@
#define SPAWN_INVISIBLE 0x8000
#define SPAWN_SMALL 0x10
-#define MERGE_MASTER 0x40
-#define MERGE_SLAVE 0x20
+#define MERGE_LEADER 0x40
+#define MERGE_FOLLOWER 0x20
void EnFloormas_Init(Actor* thisx, PlayState* play2);
void EnFloormas_Destroy(Actor* thisx, PlayState* play);
@@ -24,16 +24,16 @@ void EnFloormas_GrabLink(EnFloormas* this, PlayState* play);
void EnFloormas_Split(EnFloormas* this, PlayState* play);
void EnFloormas_Recover(EnFloormas* this, PlayState* play);
void EnFloormas_DrawHighlighted(Actor* thisx, PlayState* play);
-void EnFloormas_SmWait(EnFloormas* this, PlayState* play);
+void EnFloormas_SmallWait(EnFloormas* this, PlayState* play);
void EnFloormas_SetupBigDecideAction(EnFloormas* this);
void EnFloormas_Freeze(EnFloormas* this, PlayState* play);
void EnFloormas_TakeDamage(EnFloormas* this, PlayState* play);
void EnFloormas_Merge(EnFloormas* this, PlayState* play);
void EnFloormas_JumpAtLink(EnFloormas* this, PlayState* play);
-void EnFloormas_SmSlaveJumpAtMaster(EnFloormas* this, PlayState* play);
-void EnFloormas_SmShrink(EnFloormas* this, PlayState* play);
-void EnFloormas_SmDecideAction(EnFloormas* this, PlayState* play);
-void EnFloormas_SmWalk(EnFloormas* this, PlayState* play);
+void EnFloormas_SmallFollowerJumpAtLeader(EnFloormas* this, PlayState* play);
+void EnFloormas_SmallShrink(EnFloormas* this, PlayState* play);
+void EnFloormas_SmallDecideAction(EnFloormas* this, PlayState* play);
+void EnFloormas_SmallWalk(EnFloormas* this, PlayState* play);
void EnFloormas_Land(EnFloormas* this, PlayState* play);
void EnFloormas_Hover(EnFloormas* this, PlayState* play);
void EnFloormas_Turn(EnFloormas* this, PlayState* play);
@@ -145,7 +145,7 @@ void EnFloormas_Init(Actor* thisx, PlayState* play2) {
if (this->actor.params == SPAWN_SMALL) {
this->actor.draw = NULL;
this->actor.flags &= ~ACTOR_FLAG_0;
- this->actionFunc = EnFloormas_SmWait;
+ this->actionFunc = EnFloormas_SmallWait;
} else {
// spawn first small floormaster
this->actor.parent =
@@ -278,7 +278,6 @@ void EnFloormas_SetupLand(EnFloormas* this) {
}
void EnFloormas_SetupSplit(EnFloormas* this) {
-
Actor_SetScale(&this->actor, 0.004f);
this->actor.flags |= ACTOR_FLAG_4;
if (CHECK_FLAG_ALL(this->actor.flags, ACTOR_FLAG_7)) {
@@ -301,21 +300,21 @@ void EnFloormas_SetupSplit(EnFloormas* this) {
this->actionFunc = EnFloormas_Split;
}
-void EnFloormas_SetupSmWalk(EnFloormas* this) {
+void EnFloormas_SetupSmallWalk(EnFloormas* this) {
Animation_PlayLoopSetSpeed(&this->skelAnime, &gWallmasterWalkAnim, 4.5f);
- this->actionFunc = EnFloormas_SmWalk;
+ this->actionFunc = EnFloormas_SmallWalk;
this->actor.speed = 5.0f;
}
-void EnFloormas_SetupSmDecideAction(EnFloormas* this) {
- if (this->actionFunc != EnFloormas_SmWalk) {
+void EnFloormas_SetupSmallDecideAction(EnFloormas* this) {
+ if (this->actionFunc != EnFloormas_SmallWalk) {
Animation_PlayLoopSetSpeed(&this->skelAnime, &gWallmasterWalkAnim, 4.5f);
}
- this->actionFunc = EnFloormas_SmDecideAction;
+ this->actionFunc = EnFloormas_SmallDecideAction;
this->actor.speed = 5.0f;
}
-void EnFloormas_SetupSmShrink(EnFloormas* this, PlayState* play) {
+void EnFloormas_SetupSmallShrink(EnFloormas* this, PlayState* play) {
static Vec3f velocity = { 0.0f, 0.0f, 0.0f };
static Vec3f accel = { 0.0f, 0.0f, 0.0f };
Vec3f pos;
@@ -326,12 +325,12 @@ void EnFloormas_SetupSmShrink(EnFloormas* this, PlayState* play) {
pos.y = this->actor.world.pos.y + 15.0f;
pos.z = this->actor.world.pos.z;
EffectSsDeadDb_Spawn(play, &pos, &velocity, &accel, 150, -10, 255, 255, 255, 255, 0, 0, 255, 1, 9, true);
- this->actionFunc = EnFloormas_SmShrink;
+ this->actionFunc = EnFloormas_SmallShrink;
}
-void EnFloormas_SetupSlaveJumpAtMaster(EnFloormas* this) {
+void EnFloormas_SetupSmallFollowerJumpAtLeader(EnFloormas* this) {
Animation_Change(&this->skelAnime, &gWallmasterJumpAnim, 2.0f, 0.0f, 41.0f, ANIMMODE_ONCE, 0.0f);
- this->actionFunc = EnFloormas_SmSlaveJumpAtMaster;
+ this->actionFunc = EnFloormas_SmallFollowerJumpAtLeader;
this->actor.speed = 0.0f;
}
@@ -367,24 +366,24 @@ void EnFloormas_SetupGrabLink(EnFloormas* this, Player* player) {
void EnFloormas_SetupMerge(EnFloormas* this) {
Animation_PlayOnce(&this->skelAnime, &gWallmasterWaitAnim);
this->actionTimer = 0;
- this->smActionTimer += 1500;
+ this->smallActionTimer += 1500;
EnFloormas_MakeInvulnerable(this);
this->actionFunc = EnFloormas_Merge;
}
-void EnFloormas_SetupSmWait(EnFloormas* this) {
+void EnFloormas_SetupSmallWait(EnFloormas* this) {
EnFloormas* parent = (EnFloormas*)this->actor.parent;
EnFloormas* child = (EnFloormas*)this->actor.child;
// if this is the last remaining small floor master, kill all.
- if ((parent->actionFunc == EnFloormas_SmWait) && (child->actionFunc == EnFloormas_SmWait)) {
+ if ((parent->actionFunc == EnFloormas_SmallWait) && (child->actionFunc == EnFloormas_SmallWait)) {
Actor_Kill(&parent->actor);
Actor_Kill(&child->actor);
Actor_Kill(&this->actor);
return;
}
this->actor.draw = NULL;
- this->actionFunc = EnFloormas_SmWait;
+ this->actionFunc = EnFloormas_SmallWait;
this->actor.flags &= ~(ACTOR_FLAG_0 | ACTOR_FLAG_4);
}
@@ -436,7 +435,7 @@ void EnFloormas_Die(EnFloormas* this, PlayState* play) {
} else {
// Die
Item_DropCollectibleRandom(play, &this->actor, &this->actor.world.pos, 0x90);
- EnFloormas_SetupSmShrink(this, play);
+ EnFloormas_SetupSmallShrink(this, play);
}
}
@@ -459,10 +458,10 @@ void EnFloormas_Stand(EnFloormas* this, PlayState* play) {
if (SkelAnime_Update(&this->skelAnime)) {
if (this->actor.scale.x > 0.004f) {
EnFloormas_SetupBigWalk(this);
- } else if (this->actor.params == MERGE_SLAVE) {
- EnFloormas_SetupSmDecideAction(this);
+ } else if (this->actor.params == MERGE_FOLLOWER) {
+ EnFloormas_SetupSmallDecideAction(this);
} else {
- EnFloormas_SetupSmWalk(this);
+ EnFloormas_SetupSmallWalk(this);
}
}
}
@@ -615,7 +614,7 @@ void EnFloormas_Land(EnFloormas* this, PlayState* play) {
isOnGround = this->actor.bgCheckFlags & BGCHECKFLAG_GROUND;
if (this->actor.bgCheckFlags & BGCHECKFLAG_GROUND_TOUCH) {
- if (this->actor.params != MERGE_MASTER) {
+ if (this->actor.params != MERGE_LEADER) {
EnFloormas_MakeVulnerable(this);
}
@@ -647,11 +646,11 @@ void EnFloormas_Land(EnFloormas* this, PlayState* play) {
if (this->actionTimer == 0 && isOnGround) {
if (this->skelAnime.endFrame < 45.0f) {
this->skelAnime.endFrame = Animation_GetLastFrame(&gWallmasterJumpAnim);
- } else if (this->actor.params == MERGE_MASTER) {
+ } else if (this->actor.params == MERGE_LEADER) {
EnFloormas_SetupMerge(this);
} else {
EnFloormas_SetupStand(this);
- this->smActionTimer = 50;
+ this->smallActionTimer = 50;
}
}
}
@@ -664,7 +663,7 @@ void EnFloormas_Split(EnFloormas* this, PlayState* play) {
if (this->actor.bgCheckFlags & BGCHECKFLAG_GROUND) {
if (SkelAnime_Update(&this->skelAnime)) {
this->actor.flags |= ACTOR_FLAG_0;
- this->smActionTimer = 50;
+ this->smallActionTimer = 50;
EnFloormas_SetupStand(this);
}
Math_StepToF(&this->actor.speed, 0.0f, 1.0f);
@@ -675,16 +674,16 @@ void EnFloormas_Split(EnFloormas* this, PlayState* play) {
}
}
-void EnFloormas_SmWalk(EnFloormas* this, PlayState* play) {
+void EnFloormas_SmallWalk(EnFloormas* this, PlayState* play) {
SkelAnime_Update(&this->skelAnime);
- DECR(this->smActionTimer);
+ DECR(this->smallActionTimer);
if (Animation_OnFrame(&this->skelAnime, 0.0f) || Animation_OnFrame(&this->skelAnime, 18.0f)) {
Actor_PlaySfx(&this->actor, NA_SE_EN_FLOORMASTER_SM_WALK);
}
- if (this->smActionTimer == 0) {
- EnFloormas_SetupSmDecideAction(this);
+ if (this->smallActionTimer == 0) {
+ EnFloormas_SetupSmallDecideAction(this);
} else if (this->actor.bgCheckFlags & BGCHECKFLAG_WALL) {
this->actionTarget = this->actor.wallYaw;
EnFloormas_SetupTurn(this);
@@ -693,7 +692,7 @@ void EnFloormas_SmWalk(EnFloormas* this, PlayState* play) {
}
}
-void EnFloormas_SmDecideAction(EnFloormas* this, PlayState* play) {
+void EnFloormas_SmallDecideAction(EnFloormas* this, PlayState* play) {
Actor* primaryFloormas;
s32 isAgainstWall;
@@ -708,10 +707,10 @@ void EnFloormas_SmDecideAction(EnFloormas* this, PlayState* play) {
return;
}
- if (this->actor.params == MERGE_SLAVE) {
- if (this->actor.parent->params == MERGE_MASTER) {
+ if (this->actor.params == MERGE_FOLLOWER) {
+ if (this->actor.parent->params == MERGE_LEADER) {
primaryFloormas = this->actor.parent;
- } else if (this->actor.child->params == MERGE_MASTER) {
+ } else if (this->actor.child->params == MERGE_LEADER) {
primaryFloormas = this->actor.child;
} else {
this->actor.params = 0x10;
@@ -720,7 +719,7 @@ void EnFloormas_SmDecideAction(EnFloormas* this, PlayState* play) {
Math_ScaledStepToS(&this->actor.shape.rot.y, Actor_WorldYawTowardActor(&this->actor, primaryFloormas), 0x38E);
if (Actor_WorldDistXZToActor(&this->actor, primaryFloormas) < 80.0f) {
- EnFloormas_SetupSlaveJumpAtMaster(this);
+ EnFloormas_SetupSmallFollowerJumpAtLeader(this);
}
} else {
Math_ApproachS(&this->actor.shape.rot.y, this->actor.yawTowardsPlayer, 3, 0x71C);
@@ -730,9 +729,9 @@ void EnFloormas_SmDecideAction(EnFloormas* this, PlayState* play) {
}
}
-void EnFloormas_SmShrink(EnFloormas* this, PlayState* play) {
+void EnFloormas_SmallShrink(EnFloormas* this, PlayState* play) {
if (Math_StepToF(&this->actor.scale.x, 0.0f, 0.0015f)) {
- EnFloormas_SetupSmWait(this);
+ EnFloormas_SetupSmallWait(this);
}
this->actor.scale.z = this->actor.scale.x;
this->actor.scale.y = this->actor.scale.x;
@@ -795,12 +794,12 @@ void EnFloormas_GrabLink(EnFloormas* this, PlayState* play) {
parent = (EnFloormas*)this->actor.parent;
child = (EnFloormas*)this->actor.child;
- if (((parent->actionFunc == EnFloormas_GrabLink) || parent->actionFunc == EnFloormas_SmWait) &&
- (child->actionFunc == EnFloormas_GrabLink || child->actionFunc == EnFloormas_SmWait)) {
+ if (((parent->actionFunc == EnFloormas_GrabLink) || parent->actionFunc == EnFloormas_SmallWait) &&
+ (child->actionFunc == EnFloormas_GrabLink || child->actionFunc == EnFloormas_SmallWait)) {
- parent->actor.params = MERGE_SLAVE;
- child->actor.params = MERGE_SLAVE;
- this->actor.params = MERGE_MASTER;
+ parent->actor.params = MERGE_FOLLOWER;
+ child->actor.params = MERGE_FOLLOWER;
+ this->actor.params = MERGE_LEADER;
}
this->actor.shape.rot.x = 0;
@@ -823,13 +822,13 @@ void EnFloormas_GrabLink(EnFloormas* this, PlayState* play) {
Actor_PlaySfx(&this->actor, NA_SE_EN_FLOORMASTER_SM_STICK - SFX_FLAG);
}
-void EnFloormas_SmSlaveJumpAtMaster(EnFloormas* this, PlayState* play) {
+void EnFloormas_SmallFollowerJumpAtLeader(EnFloormas* this, PlayState* play) {
Actor* primFloormas;
SkelAnime_Update(&this->skelAnime);
- if (this->actor.parent->params == MERGE_MASTER) {
+ if (this->actor.parent->params == MERGE_LEADER) {
primFloormas = this->actor.parent;
- } else if (this->actor.child->params == MERGE_MASTER) {
+ } else if (this->actor.child->params == MERGE_LEADER) {
primFloormas = this->actor.child;
} else {
if (this->actor.bgCheckFlags & BGCHECKFLAG_GROUND_TOUCH) {
@@ -846,7 +845,7 @@ void EnFloormas_SmSlaveJumpAtMaster(EnFloormas* this, PlayState* play) {
} else if ((((primFloormas->world.pos.y - this->actor.world.pos.y) < -10.0f) &&
(fabsf(this->actor.world.pos.x - primFloormas->world.pos.x) < 10.0f)) &&
(fabsf(this->actor.world.pos.z - primFloormas->world.pos.z) < 10.0f)) {
- EnFloormas_SetupSmWait(this);
+ EnFloormas_SetupSmallWait(this);
this->collider.base.ocFlags1 |= OC1_ON;
} else if (this->actor.bgCheckFlags & BGCHECKFLAG_GROUND_TOUCH) {
this->actor.speed = 0.0f;
@@ -869,25 +868,25 @@ void EnFloormas_Merge(EnFloormas* this, PlayState* play) {
mergeCnt = 0;
- DECR(this->smActionTimer);
+ DECR(this->smallActionTimer);
parent = (EnFloormas*)this->actor.parent;
child = (EnFloormas*)this->actor.child;
- if (this->smActionTimer == 0) {
- if (parent->actionFunc != EnFloormas_SmWait) {
- EnFloormas_SetupSmShrink(parent, play);
+ if (this->smallActionTimer == 0) {
+ if (parent->actionFunc != EnFloormas_SmallWait) {
+ EnFloormas_SetupSmallShrink(parent, play);
}
- if (child->actionFunc != EnFloormas_SmWait) {
- EnFloormas_SetupSmShrink(child, play);
+ if (child->actionFunc != EnFloormas_SmallWait) {
+ EnFloormas_SetupSmallShrink(child, play);
}
} else {
- if ((parent->actionFunc != EnFloormas_SmWait) && (parent->actionFunc != EnFloormas_SmShrink)) {
+ if ((parent->actionFunc != EnFloormas_SmallWait) && (parent->actionFunc != EnFloormas_SmallShrink)) {
mergeCnt++;
}
- if ((child->actionFunc != EnFloormas_SmWait) && (child->actionFunc != EnFloormas_SmShrink)) {
+ if ((child->actionFunc != EnFloormas_SmallWait) && (child->actionFunc != EnFloormas_SmallShrink)) {
mergeCnt++;
}
}
@@ -931,7 +930,7 @@ void EnFloormas_Merge(EnFloormas* this, PlayState* play) {
func_8002F974(&this->actor, NA_SE_EN_FLOORMASTER_RESTORE - SFX_FLAG);
}
-void EnFloormas_SmWait(EnFloormas* this, PlayState* play) {
+void EnFloormas_SmallWait(EnFloormas* this, PlayState* play) {
}
void EnFloormas_TakeDamage(EnFloormas* this, PlayState* play) {
@@ -982,9 +981,9 @@ void EnFloormas_ColliderCheck(EnFloormas* this, PlayState* play) {
Actor_SetDropFlag(&this->actor, &this->collider.info, true);
if ((this->actor.colChkInfo.damageEffect != 0) || (this->actor.colChkInfo.damage != 0)) {
if (this->collider.base.colType != COLTYPE_HARD) {
- isSmall = 0;
+ isSmall = false;
if (this->actor.scale.x < 0.01f) {
- isSmall = 1;
+ isSmall = true;
}
if (isSmall && this->collider.info.acHitInfo->toucher.dmgFlags & DMG_HOOKSHOT) {
this->actor.colChkInfo.damage = 2;
@@ -1022,17 +1021,12 @@ void EnFloormas_Update(Actor* thisx, PlayState* play) {
EnFloormas* this = (EnFloormas*)thisx;
s32 pad;
- if (this->actionFunc != EnFloormas_SmWait) {
+ if (this->actionFunc != EnFloormas_SmallWait) {
if (this->collider.base.atFlags & AT_HIT) {
this->collider.base.atFlags &= ~AT_HIT;
this->actor.speed *= -0.5f;
- if (-5.0f < this->actor.speed) {
- this->actor.speed = -5.0f;
- } else {
- this->actor.speed = this->actor.speed;
- }
-
+ this->actor.speed = CLAMP_MAX(this->actor.speed, -5.0f);
this->actor.velocity.y = 5.0f;
EnFloormas_SetupLand(this);
@@ -1062,7 +1056,7 @@ void EnFloormas_Update(Actor* thisx, PlayState* play) {
CollisionCheck_SetAC(play, &play->colChkCtx, &this->collider.base);
}
- if ((this->actionFunc != EnFloormas_SmSlaveJumpAtMaster) || (this->skelAnime.curFrame < 20.0f)) {
+ if ((this->actionFunc != EnFloormas_SmallFollowerJumpAtLeader) || (this->skelAnime.curFrame < 20.0f)) {
CollisionCheck_SetOC(play, &play->colChkCtx, &this->collider.base);
}
}
diff --git a/src/overlays/actors/ovl_En_Floormas/z_en_floormas.h b/src/overlays/actors/ovl_En_Floormas/z_en_floormas.h
index c4233bf2a..4c30b8773 100644
--- a/src/overlays/actors/ovl_En_Floormas/z_en_floormas.h
+++ b/src/overlays/actors/ovl_En_Floormas/z_en_floormas.h
@@ -15,7 +15,7 @@ struct EnFloormas{
/* 0x0194 */ s16 actionTimer;
/* 0x0196 */ s16 actionTarget;
/* 0x0198 */ s16 zOffset;
- /* 0x019A */ s16 smActionTimer;
+ /* 0x019A */ s16 smallActionTimer;
/* 0x019C */ Vec3s jointTable[25];
/* 0x0232 */ Vec3s morphTable[25];
/* 0x02C8 */ ColliderCylinder collider;
diff --git a/src/overlays/actors/ovl_En_GirlA/z_en_girla.c b/src/overlays/actors/ovl_En_GirlA/z_en_girla.c
index 955fe1232..27ab2a012 100644
--- a/src/overlays/actors/ovl_En_GirlA/z_en_girla.c
+++ b/src/overlays/actors/ovl_En_GirlA/z_en_girla.c
@@ -523,7 +523,7 @@ s32 EnGirlA_CanBuy_BluePotion(PlayState* play, EnGirlA* this) {
}
s32 EnGirlA_CanBuy_Longsword(PlayState* play, EnGirlA* this) {
- if (CHECK_OWNED_EQUIP_ALT(EQUIP_TYPE_SWORD, EQUIP_INV_SWORD_BGS) &&
+ if (CHECK_OWNED_EQUIP_ALT(EQUIP_TYPE_SWORD, EQUIP_INV_SWORD_BIGGORON) &&
!CHECK_OWNED_EQUIP_ALT(EQUIP_TYPE_SWORD, EQUIP_INV_SWORD_BROKENGIANTKNIFE)) {
return CANBUY_RESULT_CANT_GET_NOW;
}
diff --git a/src/overlays/actors/ovl_En_Gm/z_en_gm.c b/src/overlays/actors/ovl_En_Gm/z_en_gm.c
index 0183b0b10..8f9be4e38 100644
--- a/src/overlays/actors/ovl_En_Gm/z_en_gm.c
+++ b/src/overlays/actors/ovl_En_Gm/z_en_gm.c
@@ -92,7 +92,7 @@ void EnGm_Destroy(Actor* thisx, PlayState* play) {
s32 func_80A3D7C8(void) {
if (LINK_AGE_IN_YEARS == YEARS_CHILD) {
return 0;
- } else if (!CHECK_OWNED_EQUIP_ALT(EQUIP_TYPE_SWORD, EQUIP_INV_SWORD_BGS)) {
+ } else if (!CHECK_OWNED_EQUIP_ALT(EQUIP_TYPE_SWORD, EQUIP_INV_SWORD_BIGGORON)) {
return 1;
} else if (CHECK_OWNED_EQUIP_ALT(EQUIP_TYPE_SWORD, EQUIP_INV_SWORD_BROKENGIANTKNIFE)) {
return 2;
diff --git a/src/overlays/actors/ovl_En_Go2/z_en_go2.c b/src/overlays/actors/ovl_En_Go2/z_en_go2.c
index 1f7b27a14..ac2d152a0 100644
--- a/src/overlays/actors/ovl_En_Go2/z_en_go2.c
+++ b/src/overlays/actors/ovl_En_Go2/z_en_go2.c
@@ -1353,7 +1353,7 @@ void EnGo2_SetupRolling(EnGo2* this, PlayState* play) {
this->actor.flags |= ACTOR_FLAG_24;
this->animTimer = 10;
this->actor.shape.yOffset = 1800.0f;
- this->actor.speed += this->actor.speed; // Speeding up
+ this->actor.speed *= 2.0f; // Speeding up
this->actionFunc = EnGo2_ContinueRolling;
}
diff --git a/src/overlays/actors/ovl_En_Horse/z_en_horse.c b/src/overlays/actors/ovl_En_Horse/z_en_horse.c
index a920c836a..97b802c8b 100644
--- a/src/overlays/actors/ovl_En_Horse/z_en_horse.c
+++ b/src/overlays/actors/ovl_En_Horse/z_en_horse.c
@@ -1001,7 +1001,7 @@ void EnHorse_UpdateSpeed(EnHorse* this, PlayState* play, f32 brakeDecel, f32 bra
EnHorse_StickDirection(&this->curStick, &stickMag, &stickAngle);
if (Math_CosS(stickAngle) <= brakeAngle) {
this->actor.speed -= brakeDecel;
- this->actor.speed = this->actor.speed < 0.0f ? 0.0f : this->actor.speed;
+ this->actor.speed = CLAMP_MIN(this->actor.speed, 0.0f);
return;
}
diff --git a/src/overlays/actors/ovl_En_Skj/z_en_skj.c b/src/overlays/actors/ovl_En_Skj/z_en_skj.c
index 25dba5db7..718436a8d 100644
--- a/src/overlays/actors/ovl_En_Skj/z_en_skj.c
+++ b/src/overlays/actors/ovl_En_Skj/z_en_skj.c
@@ -992,7 +992,7 @@ void EnSkj_WaitForSong(EnSkj* this, PlayState* play) {
player->stateFlags2 |= PLAYER_STATE2_23;
} else {
if (play->msgCtx.ocarinaMode >= OCARINA_MODE_05) {
- gSaveContext.sunsSongState = 0;
+ gSaveContext.sunsSongState = SUNSSONG_INACTIVE;
if (GET_ITEMGETINF(ITEMGETINF_16)) {
play->msgCtx.ocarinaMode = OCARINA_MODE_04;
player->unk_6A8 = &this->actor;
diff --git a/src/overlays/actors/ovl_player_actor/z_player.c b/src/overlays/actors/ovl_player_actor/z_player.c
index 81a6c1d53..5a3510a29 100644
--- a/src/overlays/actors/ovl_player_actor/z_player.c
+++ b/src/overlays/actors/ovl_player_actor/z_player.c
@@ -1212,7 +1212,7 @@ static s8 sItemActions[] = {
PLAYER_IA_BOW_LIGHT, // ITEM_BOW_LIGHT
PLAYER_IA_SWORD_KOKIRI, // ITEM_SWORD_KOKIRI
PLAYER_IA_SWORD_MASTER, // ITEM_SWORD_MASTER
- PLAYER_IA_SWORD_BGS, // ITEM_SWORD_BIGGORON
+ PLAYER_IA_SWORD_BIGGORON, // ITEM_SWORD_BIGGORON
};
static s32 (*D_80853EDC[])(Player* this, PlayState* play) = {
@@ -1221,7 +1221,7 @@ static s32 (*D_80853EDC[])(Player* this, PlayState* play) = {
func_8083485C, // PLAYER_IA_FISHING_POLE
func_808349DC, // PLAYER_IA_SWORD_MASTER
func_808349DC, // PLAYER_IA_SWORD_KOKIRI
- func_808349DC, // PLAYER_IA_SWORD_BGS
+ func_808349DC, // PLAYER_IA_SWORD_BIGGORON
func_8083485C, // PLAYER_IA_DEKU_STICK
func_8083485C, // PLAYER_IA_HAMMER
func_8083501C, // PLAYER_IA_BOW
@@ -1291,7 +1291,7 @@ static void (*D_80853FE8[])(PlayState* play, Player* this) = {
func_80833770, // PLAYER_IA_FISHING_POLE
func_80833770, // PLAYER_IA_SWORD_MASTER
func_80833770, // PLAYER_IA_SWORD_KOKIRI
- func_80833770, // PLAYER_IA_SWORD_BGS
+ func_80833770, // PLAYER_IA_SWORD_BIGGORON
func_8083377C, // PLAYER_IA_DEKU_STICK
func_80833790, // PLAYER_IA_HAMMER
func_8083379C, // PLAYER_IA_BOW
@@ -2213,7 +2213,7 @@ void func_80833A20(Player* this, s32 newMeleeWeaponState) {
u16 voiceSfx;
if (this->meleeWeaponState == 0) {
- if ((this->heldItemAction == PLAYER_IA_SWORD_BGS) && (gSaveContext.swordHealth > 0.0f)) {
+ if ((this->heldItemAction == PLAYER_IA_SWORD_BIGGORON) && (gSaveContext.swordHealth > 0.0f)) {
itemSfx = NA_SE_IT_HAMMER_SWING;
} else {
itemSfx = NA_SE_IT_SWORD_SWING;
@@ -5702,7 +5702,7 @@ s32 func_8083C544(Player* this, PlayState* play) {
if (CHECK_BTN_ALL(sControlInput->cur.button, BTN_B)) {
if (!(this->stateFlags1 & PLAYER_STATE1_22) && (Player_GetMeleeWeaponHeld(this) != 0) && (this->unk_844 == 1) &&
(this->heldItemAction != PLAYER_IA_DEKU_STICK)) {
- if ((this->heldItemAction != PLAYER_IA_SWORD_BGS) || (gSaveContext.swordHealth > 0.0f)) {
+ if ((this->heldItemAction != PLAYER_IA_SWORD_BIGGORON) || (gSaveContext.swordHealth > 0.0f)) {
func_808377DC(play, this);
return 1;
}
@@ -8014,7 +8014,7 @@ s32 func_80842AC4(PlayState* play, Player* this) {
}
s32 func_80842B7C(PlayState* play, Player* this) {
- if (this->heldItemAction == PLAYER_IA_SWORD_BGS) {
+ if (this->heldItemAction == PLAYER_IA_SWORD_BIGGORON) {
if (!gSaveContext.bgsFlag && (gSaveContext.swordHealth > 0.0f)) {
if ((gSaveContext.swordHealth -= 1.0f) <= 0.0f) {
EffectSsStick_Spawn(play, &this->bodyPartsPos[PLAYER_BODYPART_R_HAND],
diff --git a/src/code/z_camera_data.inc.c b/src/code/z_camera_data.inc.c
index b4360ffeb..9bea7df63 100644
--- a/src/code/z_camera_data.inc.c
+++ b/src/code/z_camera_data.inc.c
@@ -874,7 +874,7 @@ CameraModeValue sDataOnlyNullFlags[] = {
*=====================================================================
*/
-CameraModeValue sSetPrerendFixedModeZTargetFriendlyData[] = {
+CameraModeValue sSetPreRendFixedModeZTargetFriendlyData[] = {
CAM_FUNCDATA_INTERFACE_FIELD(CAM_INTERFACE_FIELD(CAM_LETTERBOX_MEDIUM, CAM_HUD_VISIBILITY_ALL, 0)),
};
@@ -884,15 +884,15 @@ CameraModeValue sSetPrerendFixedModeZTargetFriendlyData[] = {
*=====================================================================
*/
-CameraModeValue sSetPrerendPivotModeNormalData[] = {
+CameraModeValue sSetPreRendPivotModeNormalData[] = {
CAM_FUNCDATA_UNIQ7(60, CAM_INTERFACE_FIELD(CAM_LETTERBOX_NONE, CAM_HUD_VISIBILITY_ALL, 0)),
};
-CameraModeValue sSetPrerendPivotModeZTargetFriendlyData[] = {
+CameraModeValue sSetPreRendPivotModeZTargetFriendlyData[] = {
CAM_FUNCDATA_UNIQ7(60, CAM_INTERFACE_FIELD(CAM_LETTERBOX_MEDIUM, CAM_HUD_VISIBILITY_ALL, 0)),
};
-CameraModeValue sSetPrerendPivotModeTalkData[] = {
+CameraModeValue sSetPreRendPivotModeTalkData[] = {
CAM_FUNCDATA_KEEP0(30, 0, 4, CAM_INTERFACE_FIELD(CAM_LETTERBOX_LARGE, CAM_HUD_VISIBILITY_A_HEARTS_MAGIC_FORCE, 0)),
};
@@ -957,11 +957,11 @@ CameraModeValue sSetFree0ModeNormalData[] = {
/**
*=====================================================================
* Custom Data: FREE1 Setting
*=====================================================================
*/
-CameraModeValue sSetFree1ModeNormalData[] = {
+CameraModeValue sSetFree2ModeNormalData[] = {
CAM_FUNCDATA_INTERFACE_FIELD(CAM_INTERFACE_FIELD(CAM_LETTERBOX_IGNORE, CAM_HUD_VISIBILITY_IGNORE, UNIQUE6_FLAG_0)),
};
@@ -1459,7 +1459,7 @@ CameraModeValue sSetDirectedYawModeTalkData[] = {
*=====================================================================
*/
-CameraModeValue sNormal4ModeTalkData[] = {
+CameraModeValue sSetNormal4ModeTalkData[] = {
CAM_FUNCDATA_KEEP3(-30, 70, 200, 40, 10, 0, 5, 70, 45, 50, 10,
CAM_INTERFACE_FIELD(CAM_LETTERBOX_LARGE, CAM_HUD_VISIBILITY_A_HEARTS_MAGIC_FORCE,
KEEPON3_FLAG_7 | KEEPON3_FLAG_5)),
@@ -1965,15 +1965,15 @@ CameraMode sCamSetPivotInFrontModes[] = {
CameraMode sCamSetPreRendFixedModes[] = {
CAM_SETTING_MODE_ENTRY(CAM_FUNC_FIXD3, sDataOnlyNullFlags), // CAM_MODE_NORMAL
{ CAM_FUNC_NONE, 0, NULL }, // CAM_MODE_Z_PARALLEL
- CAM_SETTING_MODE_ENTRY(CAM_FUNC_FIXD3, sSetPrerendFixedModeZTargetFriendlyData), // CAM_MODE_Z_TARGET_FRIENDLY
- CAM_SETTING_MODE_ENTRY(CAM_FUNC_FIXD3, sSetPrerendFixedModeZTargetFriendlyData), // CAM_MODE_TALK
+ CAM_SETTING_MODE_ENTRY(CAM_FUNC_FIXD3, sSetPreRendFixedModeZTargetFriendlyData), // CAM_MODE_Z_TARGET_FRIENDLY
+ CAM_SETTING_MODE_ENTRY(CAM_FUNC_FIXD3, sSetPreRendFixedModeZTargetFriendlyData), // CAM_MODE_TALK
};
CameraMode sCamSetPreRendPivotModes[] = {
- CAM_SETTING_MODE_ENTRY(CAM_FUNC_UNIQ7, sSetPrerendPivotModeNormalData), // CAM_MODE_NORMAL
+ CAM_SETTING_MODE_ENTRY(CAM_FUNC_UNIQ7, sSetPreRendPivotModeNormalData), // CAM_MODE_NORMAL
{ CAM_FUNC_NONE, 0, NULL }, // CAM_MODE_Z_PARALLEL
- CAM_SETTING_MODE_ENTRY(CAM_FUNC_UNIQ7, sSetPrerendPivotModeZTargetFriendlyData), // CAM_MODE_Z_TARGET_FRIENDLY
- CAM_SETTING_MODE_ENTRY(CAM_FUNC_KEEP0, sSetPrerendPivotModeTalkData), // CAM_MODE_TALK
+ CAM_SETTING_MODE_ENTRY(CAM_FUNC_UNIQ7, sSetPreRendPivotModeZTargetFriendlyData), // CAM_MODE_Z_TARGET_FRIENDLY
+ CAM_SETTING_MODE_ENTRY(CAM_FUNC_KEEP0, sSetPreRendPivotModeTalkData), // CAM_MODE_TALK
};
CameraMode sCamSetPreRendSideScrollModes[] = {
@@ -2005,15 +2005,15 @@ CameraMode sCamSetFree0Modes[] = {
CAM_SETTING_MODE_ENTRY(CAM_FUNC_UNIQ6, sSetFree0ModeNormalData), // CAM_MODE_NORMAL
};
-CameraMode sCamSetFree1Modes[] = {
- CAM_SETTING_MODE_ENTRY(CAM_FUNC_UNIQ6, sSetFree1ModeNormalData), // CAM_MODE_NORMAL
+CameraMode sCamSetFree2Modes[] = {
+ CAM_SETTING_MODE_ENTRY(CAM_FUNC_UNIQ6, sSetFree2ModeNormalData), // CAM_MODE_NORMAL
};
CameraMode sCamSetPivotCornerModes[] = {
CAM_SETTING_MODE_ENTRY(CAM_FUNC_FIXD2, sSetPivotCornerModeNormalData), // CAM_MODE_NORMAL
};
-CameraMode sCamSetPivotDivingModes[] = {
+CameraMode sCamSetPivotWaterSurfaceModes[] = {
CAM_SETTING_MODE_ENTRY(CAM_FUNC_UNIQ2, sSetPivotWaterSurfaceModeNormalData), // CAM_MODE_NORMAL
CAM_SETTING_MODE_ENTRY(CAM_FUNC_UNIQ2, sSetPivotWaterSurfaceModeZParallelData), // CAM_MODE_Z_PARALLEL
};
@@ -2319,7 +2319,7 @@ CameraMode sCamSetNormal4Modes[] = {
CAM_SETTING_MODE_ENTRY(CAM_FUNC_NORM1, sSetNormal2and4ModeNormalData), // CAM_MODE_NORMAL
CAM_SETTING_MODE_ENTRY(CAM_FUNC_PARA1, sSetNormal0ModeZParallelData), // CAM_MODE_Z_PARALLEL
CAM_SETTING_MODE_ENTRY(CAM_FUNC_KEEP1, sSetNormal0ModeZTargetFriendlyData), // CAM_MODE_Z_TARGET_FRIENDLY
- CAM_SETTING_MODE_ENTRY(CAM_FUNC_KEEP3, sNormal4ModeTalkData), // CAM_MODE_TALK
+ CAM_SETTING_MODE_ENTRY(CAM_FUNC_KEEP3, sSetNormal4ModeTalkData), // CAM_MODE_TALK
CAM_SETTING_MODE_ENTRY(CAM_FUNC_BATT1, sSetNormal1ModeZTargetUnfriendlyData), // CAM_MODE_Z_TARGET_UNFRIENDLY
CAM_SETTING_MODE_ENTRY(CAM_FUNC_JUMP2, sSetNormal0ModeWallClimbData), // CAM_MODE_WALL_CLIMB
CAM_SETTING_MODE_ENTRY(CAM_FUNC_SUBJ3, sSetNormal0ModeFirstPersonData), // CAM_MODE_FIRST_PERSON
@@ -2374,9 +2374,9 @@ CameraSetting sCameraSettings[] = {
{ { 0xC5000001 }, sCamSetStart0Modes }, // CAM_SET_START0
{ { 0xC5000001 }, sCamSetStart1Modes }, // CAM_SET_START1
{ { 0x05000001 }, sCamSetFree0Modes }, // CAM_SET_FREE0
- { { 0x05000001 }, sCamSetFree1Modes }, // CAM_SET_FREE2
+ { { 0x05000001 }, sCamSetFree2Modes }, // CAM_SET_FREE2
{ { 0x85000001 }, sCamSetPivotCornerModes }, // CAM_SET_PIVOT_CORNER
- { { 0x05000003 }, sCamSetPivotDivingModes }, // CAM_SET_PIVOT_WATER_SURFACE
+ { { 0x05000003 }, sCamSetPivotWaterSurfaceModes }, // CAM_SET_PIVOT_WATER_SURFACE
{ { 0xCE000001 }, sCamSetCs0Modes }, // CAM_SET_CS_0
{ { 0x4E000001 }, sCamSetCsTwistedHallwayModes }, // CAM_SET_CS_TWISTED_HALLWAY
{ { 0x05000009 }, sCamSetForestBirdsEyeModes }, // CAM_SET_FOREST_BIRDS_EYE
@@ -957,11 +957,11 @@ CameraModeValue sSetFree0ModeNormalData[] = {
/**
*=====================================================================
- * Custom Data: FREE1 Setting
+ * Custom Data: FREE2 Setting
*=====================================================================
*/